﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
//Shame its not White.Core
using Core;
using Core.UIItems.WindowItems;
using Core.Factory;
using Core.UIItems;
using Core.UIItems.Finders;

namespace White_HelloWorld.Tests
{
    [TestFixture]
    public class DisplayFormTests
    {
        private const string path = @"..\..\..\White_HelloWorld\bin\Debug\White_HelloWorld.exe";  // :(

        private Application _app = null;
        [SetUp]
        public void Setup()
        {
            _app = Application.Launch(path);
        }

        [TearDown]
        public void Teardown()
        {
            _app.Kill();
        }

        [Test]
        public void ApplicationLaunch_NoArgs_Form1Displayed()
        {
            Application application = Application.Launch(path); 
            Window window = application.GetWindow("Form1", InitializeOption.NoCache);
            Assert.IsNotNull(window);
            Assert.IsTrue(window.DisplayState == DisplayState.Restored); //Shame it doesn't follow WinForms
            //Doesn't exit application

            //Need to kill
            application.Kill();
        }

        [Test]
        [ExpectedException(typeof(Core.UIItems.UIActionException))]
        public void ApplicationLaunch_NoArgs_Form2NotDisplayed()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("Form2", InitializeOption.NoCache);
            application.Kill();
        }

        [Test]
        public void ButtonClickable_btnClick1_ChangesText()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("White Hello World", InitializeOption.NoCache);

            Button button = window.Get<Button>("btnClick1");
            //Moves the mouse to click the button

            button.Click(); 
            Assert.AreEqual("Hello World!!", button.Name);
        }

        [Test]
        public void ButtonClickable_ClickMe_ChangesText()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("White Hello World", InitializeOption.NoCache);

            SearchCriteria searchCriteria = SearchCriteria.ByText("Click Me!");
            Button button = window.Get<Button>(searchCriteria);
            button.Click();
            Assert.AreEqual("Hello World!!", button.Name);
            application.Kill();
        }

        [Test]
        //Doesn't work?  No way to get the exception...I guess the test would fail so you would reproduce manually.
        public void ClickButton_ThrowsException()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("White Hello World", InitializeOption.NoCache);

            Button button = window.Get<Button>("throws");
            button.Click();
            Assert.AreEqual("Hello World!!", button.Name);
        }

        [Test]
        public void ClickButton_btnMsg_MessageBoxDisplayed()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("White Hello World", InitializeOption.NoCache);

            Button button = window.Get<Button>("btnMsg");
            button.Click();
            Window messageBox = window.MessageBox("");
            messageBox.Close();
            application.Kill();
        }
        [Test]
        public void ClickButton_btnLabelText_ChangesLabel()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("White Hello World", InitializeOption.NoCache);

            Button button = window.Get<Button>("btnLabelText");
            button.Click();
            Label label = window.Get<Label>("lblText");
            Assert.AreEqual("Updated", label.Text);
            application.Kill();
        }

        [Test]
        public void DisplayForm2_NotOpen_Displays()
        {
            Application application = Application.Launch(path);
            Window window = application.GetWindow("Form1", InitializeOption.NoCache);
            window.Display();  //Expected it to display Form1?
            Assert.IsTrue(window.DisplayState == DisplayState.Restored);
        }

        [Test]
        public void ClickButton_btnLabelText_ChangesLabel_ImprovedSyntax()
        {
            Application application = Application.Launch(path);
            Test2 form = new Test2(application);

            Button button = form.btnLabelText;
            button.Click();

            Assert.AreEqual("Updated", form.lblText);

            application.Kill();
        }
    }
}
